Python-Powered App

# Congratulations!

You have successfully created your first app using PyPositron!

## Next steps-

- Go to the official Positron tutorial and docs.
- Open views/index.html and main/main.py and check out the website code.

#You can write Python code here. #This code will be executed on load. #Make sure not to accidentaly indent the code. import time button=document.getElementById('button') def button_handler(): # This function will be called when the button is clicked print("Button clicked!") document.alert("The current time is "+ str(time.strftime("%H:%M:%S"))) #Use alert to show a pop-up. # You can add more code here to perform actions when the button is clicked button.addEventListener('click', button_handler)